namespace elm { 
inline ::efl::eolian::return_traits<int>::type Segment_Control::item_count_get() const
{
   int __return_value =  ::elm_obj_segment_control_item_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_selected_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_selected_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Segment_Control::item_label_get( ::efl::eolian::in_traits<int>::type idx) const
{
   const char * __return_value =  ::elm_obj_segment_control_item_label_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_insert_at( ::efl::eolian::in_traits< ::efl::canvas::Object>::type icon,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label,  ::efl::eolian::in_traits<int>::type idx) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_insert_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(icon)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_get( ::efl::eolian::in_traits<int>::type idx) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Segment_Control::item_del_at( ::efl::eolian::in_traits<int>::type idx) const
{
    ::elm_obj_segment_control_item_del_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_add( ::efl::eolian::in_traits< ::efl::canvas::Object>::type icon,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(icon)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Segment_Control::item_icon_get( ::efl::eolian::in_traits<int>::type idx) const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_segment_control_item_icon_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<int>::type Segment_Control::item_count_get() const
{
   int __return_value =  ::elm_obj_segment_control_item_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_selected_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_selected_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Segment_Control::item_label_get( ::efl::eolian::in_traits<int>::type idx) const
{
   const char * __return_value =  ::elm_obj_segment_control_item_label_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_insert_at( ::efl::eolian::in_traits< ::efl::canvas::Object>::type icon,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label,  ::efl::eolian::in_traits<int>::type idx) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_insert_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(icon)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_get( ::efl::eolian::in_traits<int>::type idx) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Segment_Control::item_del_at( ::efl::eolian::in_traits<int>::type idx) const
{
    ::elm_obj_segment_control_item_del_at(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Segment_Control::item_add( ::efl::eolian::in_traits< ::efl::canvas::Object>::type icon,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_segment_control_item_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(icon)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Segment_Control::item_icon_get( ::efl::eolian::in_traits<int>::type idx) const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_segment_control_item_icon_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(idx));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline elm::Segment_Control::operator ::elm::Segment_Control() const { return *static_cast< ::elm::Segment_Control const*>(static_cast<void const*>(this)); }
inline elm::Segment_Control::operator ::elm::Segment_Control&() { return *static_cast< ::elm::Segment_Control*>(static_cast<void*>(this)); }
inline elm::Segment_Control::operator ::elm::Segment_Control const&() const { return *static_cast< ::elm::Segment_Control const*>(static_cast<void const*>(this)); }
} }

